==> xnu-517.3.7.tar.gz: xnu-517.3.7/iokit/Drivers/platform/drvAppleIntelClock/IntelClock.cpp <==
/*
 * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
//
// Backdoor hack for Intel Clock.
//
//

#include "AppleIntelClock.h"

#define super IOService
OSDefineMetaClassAndStructors(AppleIntelClock, IOService);

extern "C" {
extern void	hardclock(void);
};

bool
AppleIntelClock::start(IOService *provider)
{
	if (!super::start(provider))
		return false;

	provider->registerInterrupt(kIRQ_Clock, 0, (IOInterruptAction) hardclock);
	provider->enableInterrupt(kIRQ_Clock);

	publishResource("IORTC", this);
	return true;
}

==> xnu-792.12.6.tar.gz: xnu-792.12.6/iokit/Drivers/platform/drvAppleIntelClock/IntelClock.cpp <==
/*
 * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_OSREFERENCE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code 
 * as defined in and that are subject to the Apple Public Source License 
 * Version 2.0 (the 'License'). You may not use this file except in 
 * compliance with the License.  The rights granted to you under the 
 * License may not be used to create, or enable the creation or 
 * redistribution of, unlawful or unlicensed copies of an Apple operating 
 * system, or to circumvent, violate, or enable the circumvention or 
 * violation of, any terms of an Apple operating system software license 
 * agreement.
 *
 * Please obtain a copy of the License at 
 * http://www.opensource.apple.com/apsl/ and read it before using this 
 * file.
 *
 * The Original Code and all software distributed under the License are 
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES, 
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT. 
 * Please see the License for the specific language governing rights and 
 * limitations under the License.
 *
 * @APPLE_LICENSE_OSREFERENCE_HEADER_END@
 */
//
// Backdoor hack for Intel Clock.
//
//

#include "AppleIntelClock.h"

#define super IOService
OSDefineMetaClassAndStructors(AppleIntelClock, IOService);

bool
AppleIntelClock::start(IOService *provider)
{
	if (!super::start(provider))
		return false;

	/*
	 * The clock is already provided by the kernel, so all we need 
	 * here is publish its availability for any IOKit client to use.
	 */
	publishResource("IORTC", this);
	return true;
}
